## [1.9.3] - 2026-03-14

### Bug Fixes
- Detect missing files when resource path coincides with datapath ([5e89a4b](https://github.com/experimaestro/experimaestro-python/commit/5e89a4b1b2a80ded7b2f70246eba59de5d705a66))

